@@ -2,7 +2,9 @@
 RAS_2D_Model:
 """
 
-import win32com.client as win32
+#import win32com.client as win32
+import os.path
+
 from pyHMT2D.Hydraulic_Models_Data import HydraulicModel
 
 from pyHMT2D.__common__ import gVerbose
@@ -29,7 +31,7 @@ class HEC_RAS_Project(object):
     """
 
     def __init__(self, title='', currentPlanName='', currentPlanFile='', geom_file_list=[],
-                 flow_file_list=[], plan_file_list=[], plans=[]):
+                 flow_file_list=[], plan_file_list=[], plans=[], terrainFileName=''):
         """HEC_RAS_Project class constructor
 
         Parameters
@@ -48,6 +50,8 @@ class HEC_RAS_Project(object):
             list of plan file names
         plans : str
             list of HEC_RAS_Plan objects
+        terrainFileName : str
+            name of terrain file (not necessary the terrain used by HEC-RAS; it is used for interpolation)
         """
 
         self.title = title
@@ -60,6 +64,8 @@ class HEC_RAS_Project(object):
         #Plans in the opened HEC-RAS project: a list of HEC_RAS_Plan objects
         self.plans = plans
 
+        self.terrainFileName = terrainFileName
+
     def set_current_plan_file_name(self, currentPlanName, currentPlanFile):
         """
 
@@ -78,6 +84,12 @@ class HEC_RAS_Project(object):
         self.currentPlanName = currentPlanName
         self.currentPlanFile = currentPlanFile
 
+    def get_current_plan_file_name(self):
+        return self.currentPlanName, self.currentPlanFile
+
+    def get_terrainFileName(self):
+        return self.terrainFileName
+
     def __del__(self):
         """ Destructor
 
@@ -282,6 +294,8 @@ class HEC_RAS_Model(HydraulicModel):
 
         print("Initializing HEC-RAS ...")
 
+        import win32com.client as win32
+
         # Should we kill all currently running HEC-RAS instances? Probably not a good idea.
         #kill_all_hec_ras()
 
@@ -304,10 +318,20 @@ class HEC_RAS_Model(HydraulicModel):
             #self._RASController = win32.Dispatch("RAS507.HECRASController")
             self._RASController = win32.DispatchEx("RAS507.HECRASController")
 
-        elif (self.getVersion() == '6.0.1'):
+        elif (self.getVersion() == '6.0.0'):
             # As of 03/21, "RAS5x.HECRASController" is the prog_id for HEC-RAS version 6 beta 1 and 2
             # This may change (check in future).
-            self._RASController = win32.gencache.EnsureDispatch('RAS5x.HECRASController')
+            # Updated 07/21: The latest official release of HEC-RAS v6.0.0's prog_id is "RAS60.HECRASController"
+            self._RASController = win32.gencache.EnsureDispatch('RAS60.HECRASController')
+
+        elif (self.getVersion() == '6.1.0'):
+            # As of 03/21, "RAS5x.HECRASController" is the prog_id for HEC-RAS version 6 beta 1 and 2
+            # This may change (check in future).
+            # Updated 07/21: The latest official release of HEC-RAS v6.1.0's prog_id is "RAS60.HECRASController"
+            self._RASController = win32.gencache.EnsureDispatch('RAS610.HECRASController')
+
+        else:
+            raise Exception("The specified version of HEC-RAS is not currently supported.")
 
         # show HEC-RAS main window
         if not self._faceless:
@@ -446,19 +470,75 @@ class HEC_RAS_Model(HydraulicModel):
             self._project = None
 
         self._project = HEC_RAS_Project(title, currentPlanName, currentPlanFile, geom_file_list,
-                                        flow_file_list, plan_file_list, plans)
+                                        flow_file_list, plan_file_list, plans, terrainFileName)
 
         #dump _project content to screen
         #print(self._project)
 
-        #create RAS_2D_Data object
-        self._ras_2d_data = RAS_2D_Data(currentPlanFile + ".hdf", terrainFileName)
+        #create RAS_2D_Data object (can't be here because the plan.hdf file exists only after the plan has been run)
+        #self._ras_2d_data = RAS_2D_Data(currentPlanFile + ".hdf", terrainFileName)
 
         print("Finished building all the plans in the project.")
 
         return currentPlanName, currentPlanFile
 
-    def get_simulation_case(self):
+    def set_current_plan(self, planName):
+        """
+
+        Parameters
+        ----------
+        planName : str
+            name of the plan to be set as current. The name should be like "Peak_flow_plan", not "p01" or "p02"
+
+        Returns
+        -------
+
+        """
+
+        #TODO: should check whether planName is in the list plans of current project
+
+        #Plan_SetCurrent(...) returns a tuple (True/False, planName)
+        ret = self._RASController.Plan_SetCurrent(planName)
+
+        if ret[0]:
+            print("Call to set_current_plan(...) is successful. Current plan is ", planName)
+        else:
+            print("Call to set_current_plan(...) failed. Current plan not changed. Check the validity of the plan name: ", planName)
+
+    def get_current_planFile(self):
+        """
+        Return the current plan file (it seems there is no function to get plan name)
+
+        Returns
+        -------
+
+        """
+
+        plan_file = self._RASController.CurrentPlanFile()
+
+        return plan_file
+
+    def load_current_plan_results(self):
+        """
+        Load the current plan results to ras_2d_data
+        Returns
+        -------
+
+        """
+
+        currentPlanName, currentPlanFile = self._project.get_current_plan_file_name()
+        terrainFileName = self._project.get_terrainFileName()
+
+        #check whether the hdf file exists
+        if not os.path.isfile(currentPlanFile):
+            raise Exception("The result HDF file for current plan does not exist. Make sure to run HEC-RAS before calling this function.")
+        elif not os.path.isfile(terrainFileName):
+            raise Exception("The specified terrain file does not exist.")
+        else:
+            self._ras_2d_data = RAS_2D_Data(currentPlanFile + ".hdf", terrainFileName)
+
+
+    def get_simulation_case(self, bReload=False):
         """Get the simulation case to RAS_2D_data
 
         Parameters
@@ -468,11 +548,13 @@ class HEC_RAS_Model(HydraulicModel):
         -------
         ras_2d_data : RAS_2D_Data
             an object from class RAS_2D_Data, which should be created before calling
+        bRelaod: bool
+            whether to reload the results from the HDF file
 
         """
 
-        if self._ras_2d_data is None:
-            raise  Exception("The requested SRH_2D_Data object is None. It should be created before requesting. Please check.")
+        if self._ras_2d_data is None or bReload:
+            self.load_current_plan_results()
 
         return self._ras_2d_data
 
@@ -554,6 +636,9 @@ class HEC_RAS_Model(HydraulicModel):
                   "False.")
 
         print("The returned messages are:")
+        print("res = ", res)
+        print("nmsg = ", nmsg)
+        print("msg = ", msg)
         for i in range(res[1]):
             print("    ", res[2][i])
 
